==> ws-v3.80.5-src.tar.gz: ws-v3.80-5/src/base1/WSCvbscrBar.cpp <==
//
// Copyright (C) 1999-2004 WideStudio Development Team
//
// Permission is hereby granted, free of charge, to any person obtaining a copy
// of this software and associated documentation files (the "Software"), to
// deal in the Software without restriction, including without limitation the
// rights to use, copy, modify, merge, publish, distribute, sublicense, and/or
// sell copies of the Software, and to permit persons to whom the Software is
// furnished to do so, subject to the following conditions:
//
// The above copyright notice and this permission notice shall be included in
// all copies or substantial portions of the Software.
//
// THE SOFTWARE IS PROVIDED "AS IS", WITHOUT WARRANTY OF ANY KIND, EXPRESS OR
// IMPLIED, INCLUDING BUT NOT LIMITED TO THE WARRANTIES OF MERCHANTABILITY,
// FITNESS FOR A PARTICULAR PURPOSE AND NONINFRINGEMENT. IN NO EVENT SHALL
// WIDESTUDIO DEVELOPMENT TEAM BE LIABLE FOR ANY CLAIM, DAMAGES OR OTHER
// LIABILITY, WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING FROM,
// OUT OF OR IN CONNECTION WITH THE SOFTWARE OR THE USE OR OTHER DEALINGS IN THE
// SOFTWARE.
//
// Except as contained in this notice, the name of WideStudio Development Team
// shall not be used in advertising or otherwise to promote the sale, use or
// other dealings in this Software without prior written authorization from
// WideStudio Development Team.

#include <WScom.h>
#include <WSCvbscrBar.h>
#include <WSCclassInformation.h>
#include <WSDappDev.h>

WSMFguiClassInitialize(WSCvbscrBar,WSCvscrBar);
WSMFversion(WSCvbscrBar,WSCvscrBar);

WSCvbscrBar::WSCvbscrBar(WSCbase* base,char* objname):
         WSCvscrBar(base,objname){
  onGuiPolicyChange(WSGIappDev()->getGuiPolicy());
}
void WSCvbscrBar::onGuiPolicyChange(long policy){
  if (policy & WS_POLICY_GRADATION){
    _grad_on = 1;
  }else{
    _grad_on = 0;
  }
  WSCvscrBar::onGuiPolicyChange(policy);
}

==> ws-v3.93.2-src.tar.gz: ws-v3.93-2/src/base1/WSCvbscrBar.cpp <==
//
// Copyright (C) 1999-2006 WideStudio/MWT Project Team
//
// Permission is hereby granted, free of charge, to any person obtaining a copy
// of this software and associated documentation files (the "Software"), to
// deal in the Software without restriction, including without limitation the
// rights to use, copy, modify, merge, publish, distribute, sublicense, and/or
// sell copies of the Software, and to permit persons to whom the Software is
// furnished to do so, subject to the following conditions:
//
// The above copyright notice and this permission notice shall be included in
// all copies or substantial portions of the Software.
//
// THE SOFTWARE IS PROVIDED "AS IS", WITHOUT WARRANTY OF ANY KIND, EXPRESS OR
// IMPLIED, INCLUDING BUT NOT LIMITED TO THE WARRANTIES OF MERCHANTABILITY,
// FITNESS FOR A PARTICULAR PURPOSE AND NONINFRINGEMENT. IN NO EVENT SHALL
// THE AUTHORS OR COPYRIGHT HOLDERS BE LIABLE FOR ANY CLAIM, DAMAGES OR OTHER
// LIABILITY, WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING FROM,
// OUT OF OR IN CONNECTION WITH THE SOFTWARE OR THE USE OR OTHER DEALINGS IN THE
// SOFTWARE.
//

#include <WScom.h>
#include <WSCvbscrBar.h>
#include <WSCclassInformation.h>
#include <WSDappDev.h>

WSMFguiClassInitialize(WSCvbscrBar,WSCvscrBar);
WSMFversion(WSCvbscrBar,WSCvscrBar);

WSCvbscrBar::WSCvbscrBar(WSCbase* base,char* objname):
         WSCvscrBar(base,objname){
// removed.. this cause executing event procedure before initializing..
//  onGuiPolicyChange(WSGIappDev()->getGuiPolicy()); 
#ifndef NO_GRADATION
  long policy = WSGIappDev()->getGuiPolicy();
  if (policy & WS_POLICY_GRADATION){
    _grad_on = 1;
  }else{
    _grad_on = 0;
  }
#endif

}
void WSCvbscrBar::onGuiPolicyChange(long policy){
#ifndef NO_GRADATION
  if (policy & WS_POLICY_GRADATION){
    _grad_on = 1;
  }else{
    _grad_on = 0;
  }
#endif
  WSCvscrBar::onGuiPolicyChange(policy);
}
